<?php
/**
 * TPC! Memory Usage Template API
 * 
 * @package TPC_Memory_Usage
 * @subpackage Template
 */

if (!defined('ABSPATH'))
	die('-1');

/**
 * Display memory usage details inside HTML comment.
 * 
 * @return void
 */
function tpcmem_display_comments() {
	global $tpcmem;
?>

<!--
TPC! Memory Usage (http://webjawns.com)
<?php echo 'Memory Usage: ' . esc_html(apply_filters('tpcmem_mb_suffix', $tpcmem->current())) . "\r"; ?>
<?php echo 'Memory Peak Usage: ' . esc_html(apply_filters('tpcmem_mb_suffix', $tpcmem->peak())) . "\r"; ?>
<?php echo 'WP Memory Limit: ' . esc_html(WP_MEMORY_LIMIT) . "\r"; ?>
<?php echo 'PHP Memory Limit: ' . esc_html($tpcmem->phpLimit()) . "\r"; ?>
<?php echo 'Checkpoints: ' . (int) $tpcmem->count() . "\r"; ?>
-->

<?php
}

/**
 * Display memory usage details within admin panel footer.
 * 
 * @return string The HTML for the admin panel footer.
 */
function tpcmem_admin_footer($html) {
	global $tpcmem;
	
	if (get_option('tpc_memory_usage_admin_footer'))
		return $html . ' | Memory Usage: ' . apply_filters('tpcmem_mb_suffix', tpcmem_graph_peak_or_current()) . '/' . @ini_get('memory_limit');
	
	return $html;
}

function tpcmem_display_dashboard_widget() {
	global $tpcmem;
	
	add_action('admin_footer', 'tpcmem_dashboard_widget_js');
	
	// Get current/peak usage
	$current = $tpcmem->current();
	$peak = $tpcmem->peak();
	
	// Make percentages out of current/peak usage
	$currentPercentage = apply_filters('tpcmem_percent_of_limit', $current);
	$peakPercentage = apply_filters('tpcmem_percent_of_limit', $peak);
	
	switch (get_option('tpc_memory_usage_graph')) {
		case 'current':
			$gPercent = $currentPercentage;
			break;
		case 'peak':
			$gPercent = $peakPercentage;
			break;
		default:
			$gPercent = false;
			break;
	}
	
	if ($gPercent) {
		$gColor = '#1c6280';
		$gColor = $gPercent > 70 ? '#cccc00' : $gColor;
		$gColor = $gPercent > 90 ? '#cc0000' : $gColor;
	}
?>
<ul>
	<li>
		<strong><?php esc_html_e('Usage Sample'); ?></strong>: 
		<span><?php echo esc_html( tpcmem_bytes_to_mb($current) . 'MB' ); ?></span>
		<span style='color: <?php echo $gColor; ?>;'>(<?php echo $currentPercentage; ?>%)</span>
	</li>
	<li>
		<strong><?php esc_html_e('Peak Usage'); ?></strong>: 
		<span><?php echo esc_html( tpcmem_bytes_to_mb($peak) . 'MB' ); ?></span>
		<span style='color: <?php echo $gColor; ?>;'>(<?php echo $peakPercentage; ?>%)</span>
	</li>
	<?php if ( 'high' == get_option('tpc_memory_usage_log') && $highest_usage = get_option('tpc_memory_usage_log_highest') ): ?>
	<li>
		<strong><?php esc_html_e('All-Time'); ?></strong>: 
		<span>
			<?php echo esc_html( tpcmem_bytes_to_mb($highest_usage['usage']) . 'MB on ' . date('n/j/y @ g:i a', $highest_usage['time']) ); ?>
			<?php echo isset($highest_usage['checkpoint_action']) && trim($highest_usage['checkpoint_action']) != '' ? "({$highest_usage['checkpoint_action']})" : ''; ?>
		</span>
	<?php endif; ?>
	
	
	<li><strong><?php esc_html_e('WP Memory Limit'); ?></strong>: <span><?php echo esc_html(WP_MEMORY_LIMIT); ?></span></li>
	<li><strong><?php esc_html_e('PHP Memory Limit'); ?></strong>: <span><?php echo esc_html($tpcmem->phpLimit()); ?></span></li>
</ul>

<?php if ( false !== $gPercent ): ?>
<div class="progressbar">
	<div class="widget" id="tpcmem_pbar_wrap">
	<div class="widget" id="tpcmem_pbar" style="width: <?php echo $gPercent; ?>%; background-color: <?php echo $gColor; ?>;">
	<div id="tpcmem_pbar_percent"><?php echo $gPercent; ?>%</div>
</div>
<!-- #tpcmem_pbar --></div>
<!-- #tpcmem_pbar_wrap --></div>
<!-- #progressbar -->
<?php endif; ?>

<p style="font-size: 9px;">
	<a href="admin.php?page=tpc-memory-usage" title="System Overview">System Overview</a> | 
	<span id="tpc_memory_usage_more_button"><a href="javascript:void(0)">More...</a></span>
	<span id="tpc_memory_usage_hide_button" class="hidden"><a href="javascript:void(0)">Hide...</a>
</p>

<div id="tpc_memory_usage_more" class="hidden">
<ul>
	<li><strong><?php esc_html_e('PHP Version'); ?></strong>: <span><?php echo esc_html(PHP_VERSION); ?></span></li>
	<li><strong><?php esc_html_e('Server Software'); ?></strong>: <span><?php echo esc_html($_SERVER['SERVER_SOFTWARE']); ?></span></li>
	<li><strong><?php esc_html_e('User Agent'); ?></strong>: <span><?php echo esc_html($_SERVER['HTTP_USER_AGENT']); ?></span></li>
</ul>
</div>
<?php
}

function tpcmem_dashboard_widget_js() {
	wp_print_scripts(array('tpcmem'));
}
