<?php
/*
Plugin Name: TPC! Memory Usage
Plugin URI: http://webjawns.com/tpc-memory-usage-for-wordpress/
Description: Used to keep track of WordPress memory usage, and system information.
Version: 0.8.2
Author: Chris Strosser
Author URI: http://webjawns.com/
*/

/**
 * TPC! Memory Usage version
 * 
 * @var string
 */
define('TPCMEM_VERSION', '0.8.2');

/**
 * TPC! Memory Usage path
 * 
 * @var string
 */
define('TPCMEM_PATH', dirname(__FILE__) . '/');

/**
 * TPC! Memory Usage basename
 * 
 * @var string
 */
define('TPCMEM_FOLDER', plugin_basename(dirname(__FILE__)));

/**
 * Whether or not to log memory usage to file.
 * 
 * This should not be used on a busy production server as it could 
 * slow things down considerably. This constant can be defined in 
 * wp-config.php.
 * 
 * @var bool
 */
if (!defined('TPCMEM_LOG_FILE'))
	define('TPCMEM_LOG_FILE', get_option('tpc_memory_usage_logging'));

/**
 * TPC! Memory Usage log file
 * 
 * @var string
 */
define('TPCMEM_LOG', TPCMEM_PATH . 'logs/tpcmem.log');

/**
 * Checkpoints table name
 * 
 * @global $wpdb
 * @var string
 */
global $wpdb;
define('TPCMEM_DB_CHECKPOINTS', $wpdb->prefix . 'tpcmem_checkpoints');

set_include_path(implode(PATH_SEPARATOR, array(
	TPCMEM_PATH . 'library',
	get_include_path(),
)));

/** Load TPC! Memory Usage */
require_once('tpcmem-admin.php');
require_once('tpcmem-checkpoints.php');
require_once('tpcmem-core.php');
require_once('tpcmem-classes.php');
require_once('tpcmem-filters.php');
require_once('tpcmem-formatting.php');
require_once('tpcmem-security.php');
require_once('tpcmem-template.php');

// Register activation/deactivation functions
register_activation_hook(__FILE__, 'tpcmem_activate');
register_deactivation_hook(__FILE__, 'tpcmem_deactivate');

// Register scripts and styles
wp_register_script('tpcmem', plugins_url('tpc-memory-usage/js/tpcmem.js'), array('jquery'), TPCMEM_VERSION, true);
wp_register_script('tpcmem-overview', plugins_url('tpc-memory-usage/js/overview.js'), array('jquery-ui-tabs'), TPCMEM_VERSION, true);
wp_register_style('tpcmem', plugins_url('tpc-memory-usage/css/tpcmem.css'), array(), TPCMEM_VERSION);